Class: REXML::Attributes
Overview
REXML::Attributes extensions
Instance Method Summary collapse
-
#to_hash ⇒ Object
A new hash of the attribute keys and values.
Instance Method Details
#to_hash ⇒ Object
Returns a new hash of the attribute keys and values.
160 161 162 163 164 |
# File 'lib/webget_ruby_ramp/xml.rb', line 160 def to_hash h=Hash.new self.keys.each{|k| h[k]=self[k]} h end |